pub unsafe extern "C" fn rcl_node_is_valid_except_context(
node: *const rcl_node_t
) -> boolExpand description
Return true if node is valid, except for the context being valid.
pub unsafe extern "C" fn rcl_node_is_valid_except_context(
node: *const rcl_node_t
) -> boolReturn true if node is valid, except for the context being valid.